==> kdevplatform_1.6.0.orig.tar.xz: kdevplatform-1.6.0/plugins/cvs/kdevcvs.desktop.cmake <==
[Desktop Entry]
Type=Service
Icon=cervisia
Exec=blubb
Comment=This plugin integrates CVS to KDevelop
Comment[bg]=Тaзи приставка вгражда CVS в KDevelop
Comment[bs]=Ovaj dodatak integriše CVS u KDevelop
Comment[ca]=Aquest connector integra CVS en KDevelop
Comment[ca@valencia]=Este connector integra CVS en KDevelop
Comment[da]=Dette plugin integrerer CVS med KDevelop
Comment[de]=Dieses Modul integriert CVS in KDevelop.
Comment[el]=Το πρόσθετο αυτό ενσωματώνει το CVS στο KDevelop
Comment[en_GB]=This plugin integrates CVS to KDevelop
Comment[es]=Este complemento integra CVS en KDevelop
Comment[et]=See plugin lõimib CVS-i KDeveloppi
Comment[fi]=Tämä liitännäinen integroi CVS:n Kdevelopiin
Comment[fr]=Ce module externe intègre CVS à KDevelop
Comment[gl]=Este complemento integra CVS en KDevelop
Comment[hu]=Ez a bővítmény integrálja a CVS-t a KDevelopba
Comment[it]=Questa estensione integra CVS in KDevelop
Comment[ja]=このプラグインは CVS を KDevelop に統合します
Comment[kk]=Бұл CVS-ты KDevelop-пен біріктіретін плагині
Comment[lv]=Šis spraudnis integrē CVS iekš KDevelop
Comment[nb]=Dette programtillegget integrerer CVS i KDevelop
Comment[nds]=Dit Moduul bett CVS na KDevelop in.
Comment[nl]=Deze plugin integreert CVS in KDevelop
Comment[pl]=Ta wtyczka udostępnia obsługę CVS w KDevelopie
Comment[pt]=Este 'plugin' integra o CVS no KDevelop
Comment[pt_BR]=Esta extensão integra o CVS ao KDevelop
Comment[ro]=Acest modul integrează CVS în KDevelop
Comment[ru]=Это расширение интегрирует поддержку CVS в KDevelop
Comment[sk]=Tento plugin integruje CVS do KDevelop.
Comment[sl]=Ta vstavek v KDevelop integrira CVS
Comment[sv]=Insticksprogrammet integrerar CVS i KDevelop
Comment[tr]=Bu eklenti CVS uygulamasını KDevelop ile bütünleştirir
Comment[ug]=بۇ قىستۇرما CVS  نى KDevelop قا يۈرۈشلەشتۈرىدۇ
Comment[uk]=За допомогою цього додатка можна інтегрувати CVS до KDevelop
Comment[x-test]=xxThis plugin integrates CVS to KDevelopxx
Comment[zh_CN]=此插件对 KDevelop 整合 CVS
Comment[zh_TW]=此外掛程式將 CVS 整合進 KDevelop 內。
Name=CVS Support
Name[bg]=Поддръжка на CVS
Name[bs]=CVS Podrška
Name[ca]=Implementació de CVS
Name[ca@valencia]=Implementació de CVS
Name[cs]=Podpora CVS
Name[da]=CVS-understøttelse
Name[de]=CVS-Unterstützung
Name[el]=Υποστήριξη CVS
Name[en_GB]=CVS Support
Name[es]=Implementación de CVS
Name[et]=CVS-i toetus
Name[fi]=CVS-tuki
Name[fr]=Prise en charge de CVS
Name[ga]=Tacaíocht CVS
Name[gl]=Soporte de CVS
Name[hu]=CVS támogatás
Name[it]=Supporto CVS
Name[ja]=CVS サポート
Name[kk]=CVS қолдауы
Name[nb]=CVS-støtte
Name[nds]=CVS-Ünnerstütten
Name[nl]=CVS-ondersteuning
Name[pa]=CVS ਸਹਿਯੋਗ
Name[pl]=Obsługa CVS
Name[pt]=Suporte para CVS
Name[pt_BR]=Suporte a CVS
Name[ru]=Поддержка CVS
Name[sk]=Podpora CVS
Name[sl]=Podpora za CVS
Name[sv]=Stöd för CVS
Name[tr]=CVS Desteği
Name[ug]=CVS قوللىشى
Name[uk]=Підтримка CVS
Name[x-test]=xxCVS Supportxx
Name[zh_CN]=CVS 支持
Name[zh_TW]=CVS 支援
GenericName=Version Control Support
GenericName[bg]=Поддръжка на управление на версиите
GenericName[bs]=Podrška za kontrolu verzija
GenericName[ca]=Implementació del control de versions
GenericName[ca@valencia]=Implementació del control de versions
GenericName[cs]=Podpora správy verzí
GenericName[da]=Understøttelse af versionstyring
GenericName[de]=Unterstützung für Versionsverwaltungssysteme
GenericName[el]=Υποστήριξη Version Control
GenericName[en_GB]=Version Control Support
GenericName[es]=Implementación de Control de Versiones
GenericName[et]=Versioonihalduse toetus
GenericName[fi]=Versionhallintatuki
GenericName[fr]=Prise en charge du contrôle de versions
GenericName[gl]=Soporte de sistemas de versións
GenericName[hu]=Verziókezelő támogatás
GenericName[it]=Supporto controllo versione
GenericName[ja]=バージョン管理のサポート
GenericName[kk]=Нұсқаларын қадағалауды қолдау
GenericName[nb]=Støtte for versjonskontroll 
GenericName[nds]=Verschoonkuntrull-Ünnerstütten
GenericName[nl]=Ondersteuning voor versiecontrole
GenericName[pl]=Obsługa kontroli wersji
GenericName[pt]=Suporte ao Controlo de Versões
GenericName[pt_BR]=Suporte a controle de versão
GenericName[ru]=Поддержка систем управления версиями
GenericName[sk]=Podpora správy verzií
GenericName[sl]=Podpora za nadzor različic
GenericName[sv]=Stöd för versionskontroll
GenericName[tr]=Sürüm Kontrol Desteği
GenericName[ug]=نەشر باشقۇرۇش قوللىشى
GenericName[uk]=Підтримка керування версіями
GenericName[x-test]=xxVersion Control Supportxx
GenericName[zh_CN]=版本控制支持
GenericName[zh_TW]=版本控制支援
ServiceTypes=KDevelop/Plugin
X-KDE-Library=kdevcvs
X-KDE-PluginInfo-Name=kdevcvs
X-KDE-PluginInfo-Author=Robert Gruber
X-KDE-PluginInfo-Version=0.1
X-KDE-PluginInfo-License=GPL
X-KDE-PluginInfo-Category=Version Control
X-KDevelop-Version=@KDEV_PLUGIN_VERSION@
X-KDevelop-Category=Global
X-KDevelop-Interfaces=org.kdevelop.IBasicVersionControl
X-KDevelop-Mode=GUI

==> kdevplatform-1.7.2.tar.xz: kdevplatform-1.7.2/plugins/cvs/kdevcvs.desktop.cmake <==
[Desktop Entry]
Type=Service
Icon=cervisia
Exec=blubb
Comment=This plugin integrates CVS to KDevelop
Comment[bg]=Тaзи приставка вгражда CVS в KDevelop
Comment[bs]=Ovaj dodatak integriše CVS u KDevelop
Comment[ca]=Aquest connector integra CVS en KDevelop
Comment[ca@valencia]=Este connector integra CVS en KDevelop
Comment[da]=Dette plugin integrerer CVS med KDevelop
Comment[de]=Dieses Modul integriert CVS in KDevelop.
Comment[el]=Το πρόσθετο αυτό ενσωματώνει το CVS στο KDevelop
Comment[en_GB]=This plugin integrates CVS to KDevelop
Comment[es]=Este complemento integra CVS en KDevelop
Comment[et]=See plugin lõimib CVS-i KDeveloppi
Comment[fi]=Tämä liitännäinen integroi CVS:n KDevelopiin
Comment[fr]=Ce module externe intègre CVS à KDevelop
Comment[gl]=Este complemento integra CVS en KDevelop
Comment[hu]=Ez a bővítmény integrálja a CVS-t a KDevelopba
Comment[it]=Questa estensione integra CVS in KDevelop
Comment[ja]=このプラグインは CVS を KDevelop に統合します
Comment[kk]=Бұл CVS-ты KDevelop-пен біріктіретін плагині
Comment[lv]=Šis spraudnis integrē CVS iekš KDevelop
Comment[nb]=Dette programtillegget integrerer CVS i KDevelop
Comment[nds]=Dit Moduul bett CVS na KDevelop in.
Comment[nl]=Deze plugin integreert CVS in KDevelop
Comment[pl]=Ta wtyczka udostępnia obsługę CVS w KDevelopie
Comment[pt]=Este 'plugin' integra o CVS no KDevelop
Comment[pt_BR]=Esta extensão integra o CVS ao KDevelop
Comment[ro]=Acest modul integrează CVS în KDevelop
Comment[ru]=Это расширение интегрирует поддержку CVS в KDevelop
Comment[sk]=Tento plugin integruje CVS do KDevelop.
Comment[sl]=Ta vstavek v KDevelop integrira CVS
Comment[sv]=Insticksprogrammet integrerar CVS i KDevelop
Comment[tr]=Bu eklenti CVS uygulamasını KDevelop ile bütünleştirir
Comment[ug]=بۇ قىستۇرما CVS  نى KDevelop قا يۈرۈشلەشتۈرىدۇ
Comment[uk]=За допомогою цього додатка можна інтегрувати CVS до KDevelop
Comment[x-test]=xxThis plugin integrates CVS to KDevelopxx
Comment[zh_CN]=此插件对 KDevelop 整合 CVS
Comment[zh_TW]=此外掛程式將 CVS 整合進 KDevelop 內。
Name=CVS Support
Name[bg]=Поддръжка на CVS
Name[bs]=CVS Podrška
Name[ca]=Implementació de CVS
Name[ca@valencia]=Implementació de CVS
Name[cs]=Podpora CVS
Name[da]=CVS-understøttelse
Name[de]=CVS-Unterstützung
Name[el]=Υποστήριξη CVS
Name[en_GB]=CVS Support
Name[es]=Implementación de CVS
Name[et]=CVS-i toetus
Name[fi]=CVS-tuki
Name[fr]=Prise en charge de CVS
Name[ga]=Tacaíocht CVS
Name[gl]=Soporte de CVS
Name[hu]=CVS támogatás
Name[it]=Supporto CVS
Name[ja]=CVS サポート
Name[kk]=CVS қолдауы
Name[nb]=CVS-støtte
Name[nds]=CVS-Ünnerstütten
Name[nl]=CVS-ondersteuning
Name[pa]=CVS ਸਹਿਯੋਗ
Name[pl]=Obsługa CVS
Name[pt]=Suporte para CVS
Name[pt_BR]=Suporte a CVS
Name[ru]=Поддержка CVS
Name[sk]=Podpora CVS
Name[sl]=Podpora za CVS
Name[sv]=Stöd för CVS
Name[tr]=CVS Desteği
Name[ug]=CVS قوللىشى
Name[uk]=Підтримка CVS
Name[x-test]=xxCVS Supportxx
Name[zh_CN]=CVS 支持
Name[zh_TW]=CVS 支援
GenericName=Version Control Support
GenericName[bg]=Поддръжка на управление на версиите
GenericName[bs]=Podrška za kontrolu verzija
GenericName[ca]=Implementació del control de versions
GenericName[ca@valencia]=Implementació del control de versions
GenericName[cs]=Podpora správy verzí
GenericName[da]=Understøttelse af versionstyring
GenericName[de]=Unterstützung für Versionsverwaltungssysteme
GenericName[el]=Υποστήριξη Version Control
GenericName[en_GB]=Version Control Support
GenericName[es]=Implementación de Control de Versiones
GenericName[et]=Versioonihalduse toetus
GenericName[fi]=Versionhallintatuki
GenericName[fr]=Prise en charge du contrôle de versions
GenericName[gl]=Soporte de sistemas de versións
GenericName[hu]=Verziókezelő támogatás
GenericName[it]=Supporto controllo versione
GenericName[ja]=バージョン管理のサポート
GenericName[kk]=Нұсқаларын қадағалауды қолдау
GenericName[nb]=Støtte for versjonskontroll 
GenericName[nds]=Verschoonkuntrull-Ünnerstütten
GenericName[nl]=Ondersteuning voor versiecontrole
GenericName[pl]=Obsługa kontroli wersji
GenericName[pt]=Suporte ao Controlo de Versões
GenericName[pt_BR]=Suporte a controle de versão
GenericName[ru]=Поддержка систем управления версиями
GenericName[sk]=Podpora správy verzií
GenericName[sl]=Podpora za nadzor različic
GenericName[sv]=Stöd för versionskontroll
GenericName[tr]=Sürüm Kontrol Desteği
GenericName[ug]=نەشر باشقۇرۇش قوللىشى
GenericName[uk]=Підтримка керування версіями
GenericName[x-test]=xxVersion Control Supportxx
GenericName[zh_CN]=版本控制支持
GenericName[zh_TW]=版本控制支援
ServiceTypes=KDevelop/Plugin
X-KDE-Library=kdevcvs
X-KDE-PluginInfo-Name=kdevcvs
X-KDE-PluginInfo-Author=Robert Gruber
X-KDE-PluginInfo-Version=0.1
X-KDE-PluginInfo-License=GPL
X-KDE-PluginInfo-Category=Version Control
X-KDevelop-Version=@KDEV_PLUGIN_VERSION@
X-KDevelop-Category=Global
X-KDevelop-Interfaces=org.kdevelop.IBasicVersionControl
X-KDevelop-Mode=GUI
